@@ -38,10 +38,10 @@ class SMTRestlerRouter extends Restler
     
     /**
      * REST routes min cache size. Used to track empty arrays stored in routes cache.
-     * Current size of the cache file is more than 260Ko 
+     * Current size of the cache file is more than 800Ko 
      * @var integer
      */
-    const MIN_CACHE_SIZE = 200000;
+    const MIN_CACHE_SIZE = 800000;
     
     /**
      * @var string
@@ -121,8 +121,8 @@ class SMTRestlerRouter extends Restler
     public function loadRoutes( array &$service_class_names )
     {
         $routeChecked = self::isRouteChecked();
-        
-        if ( ($routeChecked != TRUE) || !$this->productionMode )
+
+        if ( ($routeChecked != TRUE) || !$this->productionMode || !file_exists( Defaults::$cacheDirectory.DIRECTORY_SEPARATOR.'routes.php' ) )
         {            
            $this->checkRoutes( $service_class_names );
         }
@@ -130,10 +130,12 @@ class SMTRestlerRouter extends Restler
 //         $this->loadCache();
         
         //if loading fails, force a check of the routes
-        if ( $this->productionMode && !$this->cached )
+        $routes = isset($this->cache)? $this->cache->get('routes') : NULL;
+        if ( $this->productionMode && (!isset($routes) || !is_array($routes) ) )//!$this->cached )
         {
             self::updateRouteCacheCheckedStatus(FALSE);
             $this->checkRoutes( $service_class_names );
+            SMTLogger::getInstance()->trace( "checkRoutes $this->cached");
 //             $this->loadCache();
         }
     }
@@ -184,7 +186,7 @@ class SMTRestlerRouter extends Restler
                     	
                     	//remove everything from directory
                     	array_map('unlink', glob(Defaults::$cacheDirectory.'/*'));
-    
+
                     	//if cache is invalid, reset its flag to force the reload
                     	$this->cached = NULL;
                     }
