@@ -13,7 +13,7 @@
 // *********************************************************
 namespace app\http;
 
-use app\serviceshelper\otdr\SMTOtdrTraceFileUtil;
+use app\serviceshelper\otdr\SMTBaseOtdrTraceFileUtil;
 
 use app\util\SMTLogger;
 
@@ -42,6 +42,15 @@ class SMTSessionDirectoryUtil
 	 */
 	const DEFAULT_OTDR_FILE_NAME = "measure_%s_%s.sor";
 	
+	/**
+	 * OTDR default file name on session directory
+	 *
+	 * @param $portNumber
+	 * @param $operationId
+	 * @var string
+	 */
+	const BASE_OTDR_FILE_NAME = "measure_%s_%s%s";
+	
 	/**
 	 * Maximum number of OTDR files stored in session: 10
 	 * Those files can be used as reference of new monitoring test
@@ -65,10 +74,11 @@ class SMTSessionDirectoryUtil
  * Build otdr file name stored on SmartOtu session directory
  * @param int $portNumber The port number where the acquisition was done.
  * @param string $operationId The operation id of the measure
+ * @param string $smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION
  */
-static function buildOtdrFileName( $portNumber, $operationId )
+	static function buildOtdrFileName( $portNumber, $operationId, $smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION)
 {
-    return sprintf(self::DEFAULT_OTDR_FILE_NAME, $portNumber, $operationId);
+	return sprintf(self::BASE_OTDR_FILE_NAME, $portNumber, $operationId, $smartAcqTraceExtension);
 }	
 	
 /**
@@ -78,11 +88,11 @@ static function buildOtdrFileName( $portNumber, $operationId )
  * 
  * @return string The acquisition file path in SmartOtu directory
  */
-static function getLastOTDRTraceFileNameFromSession( $portNumber )
+static function getLastOTDRTraceFileNameFromSession( $portNumber, $smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION)
 {
 	$acquisitionTrace = NULL;
 	$sessionDirectory = self::createSessionDirectoryIfNeeded();
-	foreach ( glob( $sessionDirectory.self::buildOtdrFileName( $portNumber, "*" ) ) as $file )
+	foreach ( glob( $sessionDirectory.self::buildOtdrFileName( $portNumber, "*", $smartAcqTraceExtension) ) as $file )
 	{
 		$acquisitionTrace = $file;
 		break;
@@ -131,39 +141,188 @@ static function getOTDRTraceFileNameFromSession( $otdrShortFileName )
  * @param string $filePath
  * @return string The new file path in SmartOtu directory
  */
-public static function backupOTDRTraceToSessionDirectory( $filePath, $portNumber, $operationId )
+public static function backupOTDRTraceToSessionDirectory( $filePath, $portNumber, $operationId, $smartAcq = FALSE )
 {
     self::removeSessionsDirectoriesIfNeeded();
     
 	$sessionDirectory = self::createSessionDirectoryIfNeeded();
     self::checkOTDRFilesCountInSession();
+    
+    $smartAcqTraceExtension = $smartAcq? SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($filePath) : SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION;
 	
-	$newFilePath = $sessionDirectory.self::buildOtdrFileName( $portNumber, $operationId ) ;
+    $newFilePath = $sessionDirectory.self::buildOtdrFileName( $portNumber, $operationId, $smartAcqTraceExtension) ;
 
 	if ( !copy( $filePath, $newFilePath ) )
 	{
-		throw new SMTIOException( SMTIOException::COPY_FAILURE, $newFilePath );
+		throw new SMTIOException( SMTIOException::COPY_FAILURE, 'from '.$filePath.' to '.$newFilePath );
 	}
 
 	return $newFilePath;
 }
 
 /**
- * Backup the last monitoring OTDR file of the given test to SmartOTU directory by user session.
+ * Search if the last acquisition of the current test is a localisation
+ * 
+ * @param integer $testId
+ * @param integer $portNumber
+ * 
+ * @return boolean
+ */
+public static function hasLastAcquisitionLocalisation( $testId, $portNumber )
+{
+	$hasLastAcquisitionLoc = FALSE;
+	$filePath = SMTBaseOtdrTraceFileUtil::buildLastMonitoringDetectionTraceNameOnOtu($testId, $portNumber);
+	$filePathLoc = SMTBaseOtdrTraceFileUtil::buildLastMonitoringLocalisationTraceNameOnOtu($testId, $portNumber);
+	
+	//CSOR
+	$filePath = SMTBaseOtdrTraceFileUtil::replaceExtension($filePath, SMTBaseOtdrTraceFileUtil::OTDR_FILE_CSOR_EXTENSION);
+	if ( !file_exists( $filePath) )
+	{
+		//MSOR
+		$filePath = SMTBaseOtdrTraceFileUtil::replaceExtension($filePath, SMTBaseOtdrTraceFileUtil::OTDR_FILE_MSOR_EXTENSION);
+		if ( !file_exists( $filePath) )
+		{
+			//SOR
+			$filePath = SMTBaseOtdrTraceFileUtil::replaceExtension($filePath, SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION);
+		}
+	}
+	//CSOR
+	$filePathLoc = SMTBaseOtdrTraceFileUtil::replaceExtension($filePathLoc, SMTBaseOtdrTraceFileUtil::OTDR_FILE_CSOR_EXTENSION);
+	if ( !file_exists( $filePathLoc) )
+	{
+		//MSOR
+		$filePathLoc = SMTBaseOtdrTraceFileUtil::replaceExtension($filePathLoc, SMTBaseOtdrTraceFileUtil::OTDR_FILE_MSOR_EXTENSION);
+		if ( !file_exists( $filePathLoc) )
+		{
+			//SOR
+			$filePathLoc = SMTBaseOtdrTraceFileUtil::replaceExtension($filePathLoc, SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION);
+		}
+	}
+	
+	if ( ($filePath == NULL) || !file_exists( $filePath) )
+	{
+		if ( $filePathLoc!= NULL && file_exists( $filePathLoc) )
+		{
+			$hasLastAcquisitionLoc= TRUE;
+		}
+	}
+	else
+	{
+		if ( ($filePathLoc!= NULL) && file_exists( $filePathLoc) )
+		{
+			// on doit prendre le fichier le plus recent
+			$hasLastAcquisitionLoc= (filemtime($filePathLoc) >= filemtime($filePath) );
+		}
+	}
+	return $hasLastAcquisitionLoc;
+}
+
+/**
+ * Backup the last monitoring OTDR file (SOR,MSOR,CSOR) of the given test to SmartOTU directory by user session.
  *
  * @param integer $testId
+ * @param boolean smartAcq FALSE to limit the search to sor file
+ * 
  * @return string The new file path in SmartOtu directory
  */
-public static function backupLastMonitoringTraceToSessionDirectory( $testId, $portNumber )
+public static function backupLastMonitoringTraceToSessionDirectory( $testId, $portNumber, &$isLoc, $smartAcq = TRUE )
 {
 	self::removeSessionsDirectoriesIfNeeded();
 	self::checkOTDRFilesCountInSession();
-	$filePath = SMTOtdrTraceFileUtil::buildLastMonitoringDetectionTraceNameOnOtu($testId, $portNumber);
-	$newFilePath = SMTOtdrTraceFileUtil::buildLastMonitoringDetectionTraceNameOnSmartOtu($testId, $portNumber) ;
-
-	if ( !copy( $filePath, $newFilePath ) )
+	
+	$filePath = SMTBaseOtdrTraceFileUtil::buildLastMonitoringDetectionTraceNameOnOtu($testId, $portNumber);
+	$filePathLoc = SMTBaseOtdrTraceFileUtil::buildLastMonitoringLocalisationTraceNameOnOtu($testId, $portNumber);	
+	$newFilePath = SMTBaseOtdrTraceFileUtil::buildLastMonitoringDetectionTraceNameOnSmartOtu($testId, $portNumber) ;
+	$newFilePathLoc = $newFilePath;
+	$isLoc = FALSE;
+	
+	if ( $smartAcq )
 	{
-		throw new SMTIOException( SMTIOException::COPY_FAILURE, $newFilePath );
+		//CSOR
+		$filePath = SMTBaseOtdrTraceFileUtil::replaceExtension($filePath, SMTBaseOtdrTraceFileUtil::OTDR_FILE_CSOR_EXTENSION);
+		if ( file_exists( $filePath) )
+		{
+			$newFilePath= SMTBaseOtdrTraceFileUtil::replaceExtension($newFilePath, SMTBaseOtdrTraceFileUtil::OTDR_FILE_CSOR_EXTENSION);
+		}
+		else
+		{
+			//MSOR
+			$filePath = SMTBaseOtdrTraceFileUtil::replaceExtension($filePath, SMTBaseOtdrTraceFileUtil::OTDR_FILE_MSOR_EXTENSION);
+			if ( file_exists( $filePath) )
+			{
+				$newFilePath= SMTBaseOtdrTraceFileUtil::replaceExtension($newFilePath, SMTBaseOtdrTraceFileUtil::OTDR_FILE_MSOR_EXTENSION);
+			}
+			//SOR
+			else
+			{
+				$filePath = SMTBaseOtdrTraceFileUtil::replaceExtension($filePath, SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION);
+				$newFilePath= SMTBaseOtdrTraceFileUtil::replaceExtension($newFilePath, SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION);
+			}
+		}
+		
+		
+		//CSOR
+		$filePathLoc= SMTBaseOtdrTraceFileUtil::replaceExtension($filePathLoc, SMTBaseOtdrTraceFileUtil::OTDR_FILE_CSOR_EXTENSION);
+		if ( file_exists( $filePathLoc) )
+		{
+			$newFilePathLoc= SMTBaseOtdrTraceFileUtil::replaceExtension($newFilePathLoc, SMTBaseOtdrTraceFileUtil::OTDR_FILE_CSOR_EXTENSION);
+		}
+		else
+		{
+			//MSOR
+			$filePathLoc = SMTBaseOtdrTraceFileUtil::replaceExtension($filePathLoc, SMTBaseOtdrTraceFileUtil::OTDR_FILE_MSOR_EXTENSION);
+			if ( file_exists( $filePathLoc) )
+			{
+				$newFilePathLoc= SMTBaseOtdrTraceFileUtil::replaceExtension($newFilePathLoc, SMTBaseOtdrTraceFileUtil::OTDR_FILE_MSOR_EXTENSION);
+			}
+			//SOR
+			else
+			{
+				$filePathLoc = SMTBaseOtdrTraceFileUtil::replaceExtension($filePathLoc, SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION);
+				$newFilePathLoc= SMTBaseOtdrTraceFileUtil::replaceExtension($newFilePathLoc, SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION);
+			}
+		}
+	}
+
+	if ( $filePath== NULL || !file_exists( $filePath) )
+	{
+		if ( $filePathLoc == NULL || !file_exists( $filePathLoc) )
+		{
+			SMTLogger::getInstance()->trace( sprintf( "Failed to retrieve last monitoring OTDR acquisition trace: %s ", $filePath), SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
+			throw new SMTIOException( SMTIOException::FILE_NOT_FOUND, $filePath);
+		}
+		else
+		{
+			$isLoc = TRUE;
+		}
+	}
+	else
+	{
+		if ( $filePathLoc!= NULL && file_exists( $filePathLoc) )
+		{
+			// on doit prendre le fichier le plus recent
+			$isLoc = (filemtime($filePathLoc) >= filemtime($filePath) ); 
+		}
+	}
+
+	if ( $isLoc )
+	{
+		SMTLogger::getInstance()->trace( sprintf( "copy last monitoring LOC OTDR acquisition trace %s to %s", $filePathLoc, $newFilePathLoc), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
+		
+		if ( !copy( $filePathLoc, $newFilePathLoc) )
+		{
+			throw new SMTIOException( SMTIOException::COPY_FAILURE, $newFilePathLoc);
+		}
+		return $newFilePathLoc;
+	}
+	else
+	{
+		SMTLogger::getInstance()->trace( sprintf( "copy last monitoring DET OTDR acquisition trace %s to %s", $filePath, $newFilePath), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
+		
+		if ( !copy( $filePath, $newFilePath ) )
+		{
+			throw new SMTIOException( SMTIOException::COPY_FAILURE, $newFilePath );
+		}
 	}
 
 	return $newFilePath;
