@@ -368,7 +368,8 @@ class SMTOtuApi
     {
     	return sprintf( self::CMD_get_MOD_Name, $moduleId );
     }
-        
+    
+    const CMD_check_module_compatibility_with_switch = 'OTU:MODU:SWITCH:COMP?';
     //modems configuration:
 //     const CMD_modem_media_config = 'OTU:MED:GET? BACK';
 //     const CMD_modem_speed = 'otu:modem:conf:spee? %s'; //INT1 ...
@@ -946,7 +947,9 @@ class SMTOtuApi
     const CMD_scan_osu = 'OTU:SWITCH:OSUJ:SCAN?';   // on ne gere plus les OSUs Dicon
     const CMD_get_osuj_desc = 'OTU:SWITCH:OSUJ:DESC? %s';
     const CMD_is_osu_present = 'OTU:SWITCH:OSUS:PRESENT? %s,%s';//N_Osus,ALL/JDSU/DICON     
-     
+    const CMD_get_osu_det_type = 'OTU:SWITCH:OSUS:DETType?';
+    const CMD_get_osu_conf_type = 'OTU:SWITCH:OSUS:CONFType?';
+    
     const CMD_get_osu_desc = 'OTU:SWITCH:OSUS:DESC? %s';
     const CMD_get_osuj_idn = 'OTU:SWITCH:DEBUG:JDSU:IDN? %d';
     const CMD_get_osuj_select = 'OTU:SWITCH:DEBUG:SELECT EXT';
@@ -967,8 +970,15 @@ class SMTOtuApi
     const CMD_switch_detect_calib_SerialNum = 'OTU:SWITCH:CONFIG:DETECT:SER? %d,%s'; //0,INT/OSU1/OSU2 ... ... OSU31//Detection from calibration
     const CMD_get_switch_ports = 'OTU:SWITCH:CONF:PORT? %d';    //0/1/2/3/...31
     const CMD_get_switch_jdsu_idn = 'OTU:SWITCH:OSXJdsu:IDN? %d';
-    const CMD_switch_detect_Serial_Number_List = 'OTU:SWITCH:OSXJdsu:DETSERial?';
-    const CMD_switch_config_Serial_Number_List = 'OTU:SWITCH:OSXJdsu:CONFSERial?';
+    const CMD_switch_detect_Serial_Number_List = 'OTU:SWITCH:OSUS:DETSERial?';
+    const CMD_switch_config_Serial_Number_List = 'OTU:SWITCH:OSUS:CONFSERial?';
+    const CMD_switch_osx_detect_Serial_Number_List = 'OTU:SWITCH:OSXJdsu:DETSERial?';
+    const CMD_switch_osx_config_Serial_Number_List = 'OTU:SWITCH:OSXJdsu:CONFSERial?';
+    
+    //SWITCH MOLEX
+    const CMD_get_switch_molex_idn = 'OTU:SWITCH:MOLEX:IDN? %d';
+    const CMD_get_switch_molex_available = 'OTU:SWITCH:MOLEX:AVAIlable?'; //TRUE/FALSE
+    const CMD_get_switch_config_type = 'OTU:SWITCH:CONFIG:TYPE? %d'; //OSX_JDSU, MOLEX
     
     //OTAU NEW FUNCTIONS to handle big configurations of ROTAUs
     const CMD_compare_switches = 'OTU:SWITCH:COMPAR:MACRO? %d';//0/1... for Macroswitchid, returns SAME,DIFF,MISSCONF,MISSDET
@@ -1032,7 +1042,7 @@ class SMTOtuApi
     /**
      * //module, switches number, switch ASCII buffer// auto Config (AUTO, MANUAL) // pulse //range KM // duration s // refraction index // wavelength // resolution // function// short acq
      */
-    const CMD_acquisition_otdr_SI = 'OTU:MEALINK:SI:CONFIG? %s,%d,%s,%s,%d,%F,%d,%F,%d,%d,"%s",%s';
+    const CMD_acquisition_otdr_SI = 'OTU:MEALINK:SI:SWN:CONFIG? %s,%d,%s,%s,%d,%F,%d,%F,%d,%d,"%s",%s';
     /**
      * Execute a measurement on demand command
      *
@@ -1059,7 +1069,7 @@ class SMTOtuApi
     /**
      * //module, switches number, switch ASCII buffer// auto Config (AUTO, MANUAL) // pulse //range KM // duration s // refraction index // wavelength // resolution // function// short acq// frequency
      */
-    const CMD_acquisition_DWDM_SI= 'OTU:MEALINK:SI:DWDM? %s,%d,%s,%s,%d,%F,%d,%F,%d,%d,"%s",%s,%d';
+    const CMD_acquisition_DWDM_SI= 'OTU:MEALINK:SI:SWN:DWDM? %s,%d,%s,%s,%d,%F,%d,%F,%d,%d,"%s",%s,%d';
     /**
      * Execute a dwdm measurement on demand command
      *
@@ -1182,26 +1192,11 @@ class SMTOtuApi
     //****************
     //* Links
     //***************
-    /**
-     * linkId
-     */    
-    const CMD_link_get = 'OTU:LINK:GET? %d';    
-    /**
-     * Get link config command
-     * 
-     * @param number $linkId
-     * 
-     * @return string
-     */
-    static function getlinkCommand( $linkId )
-    {
-    	return sprintf( self::CMD_link_get, $linkId );
-    }
     
     /**
      * linkId
      */
-    const CMD_link_utf8_get = 'OTU:LINK:UTF8:GET? %d';
+    const CMD_link_swn_get = 'OTU:LINK:SWN:GET? %d';
     /**
      * Get link utf8 config command
      *
@@ -1211,7 +1206,7 @@ class SMTOtuApi
      */
     static function getlinkUtf8Command( $linkId )
     {
-    	return sprintf( self::CMD_link_utf8_get, $linkId );
+    	return sprintf( self::CMD_link_swn_get, $linkId );
     }
     
     const CMD_link_list = 'OTU:LINK:LIST?';
@@ -1386,30 +1381,11 @@ class SMTOtuApi
     	return sprintf( self::CMD_link_utf8_rename, $linkId, $newlinkName);
     }
     
-    /**
-     * link name //availability [KO, OK] //timeslot [NONE,CI10MN,CP10MN,CI5MN,CP5MN,C135,C246] // [MOD1,MOD2]// traffic [NO,YES]// switch# //switch buffer
-     */
-    const CMD_link_add = 'OTU:LINK:ADD? "%s",%s,%s,%s,%s,%d,%s'; 
-
-    /**
-     * Build add link command
-     * 
-     * @param string $linkName
-     * @param number $moduleRunningNumber //1 or 2
-     * @param number $switchCount
-     * @param string $switchBuffer
-     * 
-     * @return string
-     */
-    static function addLinkCommand( $linkName, $moduleRunningNumber, $switchCount, $switchBuffer )
-    {
-    	return sprintf( self::CMD_link_add, $linkName, self::RES_OK, self::RES_NONE, self::RES_MOD.$moduleRunningNumber, self::RES_YES, $switchCount, $switchBuffer);
-    }     
 
     /**
      * utf8 link name //link name //availability [KO, OK] //timeslot [NONE,CI10MN,CP10MN,CI5MN,CP5MN,C135,C246] // [MOD1,MOD2]// traffic [NO,YES]// switch# //switch buffer
      */
-    const CMD_link_utf8_add = 'OTU:LINK:UTF8:ADD? "%s","%s",%s,%s,%s,%s,%d,%s';
+    const CMD_link_swn_add = 'OTU:LINK:SWN:ADD? "%s","%s",%s,%s,%s,%s,%d,%s';
     
     /**
      * Build add link command
@@ -1424,7 +1400,7 @@ class SMTOtuApi
      */
     static function addLinkUtf8Command( $utf8LinkName, $linkName, $moduleRunningNumber, $switchCount, $switchBuffer )
     {
-    	return sprintf( self::CMD_link_utf8_add, $utf8LinkName, $linkName, self::RES_OK, self::RES_NONE, self::RES_MOD.$moduleRunningNumber, self::RES_YES, $switchCount, $switchBuffer);
+    	return sprintf( self::CMD_link_swn_add, $utf8LinkName, $linkName, self::RES_OK, self::RES_NONE, self::RES_MOD.$moduleRunningNumber, self::RES_YES, $switchCount, $switchBuffer);
     }    
     /**
      * @param number linkId
