@@ -247,6 +247,12 @@ define("THRESHOLD_LEVEL_EXCEEDED","超过阈值");
 define("CONNECTOR_FAILURE","连接器");
 define("CONNECTOR_FIBER_CUT_FAILURE","光纤切割（连接器)");
 define("CONNECTOR_ATTENUATION_FAILURE","超过阈值 (连接器)");
+define("SPLICE_BREAK","接头损坏或APC跳线断开");
+define("CONNECTOR_BREAK","跳线断开或过度弯曲");
+define("FIBER_BREAK","纤维断裂");
+define("SPLICE_ATTENUATION","接头或APC跳线上的光纤弯曲");
+define("CONNECTOR_ATTENUATION","跳线弯曲，脏，松");
+define("FIBER_ATTENUATION","纤维弯曲");
 define("UNKNOW_ALARM","未知的告警");
 define("UNKNOWN_CAUSE","未知的原因");
 ?>
