@@ -247,6 +247,12 @@ define("THRESHOLD_LEVEL_EXCEEDED","Threshold crossed");
 define("CONNECTOR_FAILURE","Connector");
 define("CONNECTOR_FIBER_CUT_FAILURE","Fiber Cut (Connector)");
 define("CONNECTOR_ATTENUATION_FAILURE","Attenuation (Connector)");
+define("SPLICE_BREAK","Splice broken or APC patchcord disconnected");
+define("CONNECTOR_BREAK","Patchcord disconnected or excessive bending");
+define("FIBER_BREAK","Fiber Break");
+define("SPLICE_ATTENUATION","Fiber bending on splice or on APC patchcord");
+define("CONNECTOR_ATTENUATION","Patchcord bending, dirty, loose");
+define("FIBER_ATTENUATION","Fiber bending");
 define("UNKNOW_ALARM","Unknown alarm");
 define("UNKNOWN_CAUSE","Unknown cause");
 ?>
