@@ -248,6 +248,12 @@ define("THRESHOLD_LEVEL_EXCEEDED","Dépassement de niveau");
 define("CONNECTOR_FAILURE","Connecteur");
 define("CONNECTOR_FIBER_CUT_FAILURE","Coupure fibre (Connecteur)");
 define("CONNECTOR_ATTENUATION_FAILURE","Dépassement de niveau (Connecteur)");
+define("SPLICE_BREAK","Epissure cassée ou APC patchcord déconnecté");
+define("CONNECTOR_BREAK","Patchcord déconnecté ou courbure excessive");
+define("FIBER_BREAK","Coupure Fibre");
+define("SPLICE_ATTENUATION","Courbure fibre au niveau d'une épissure ou d'un patchcord APC");
+define("CONNECTOR_ATTENUATION","Courbure au niveau d'un connecteur, connecteur sale ou mal connecté");
+define("FIBER_ATTENUATION","Courbure fibre");
 define("UNKNOW_ALARM","Alarme inconnue");
 define("UNKNOWN_CAUSE","Cause inconnue");
 ?>
