@@ -364,14 +364,43 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
      */
     function updateOtuDateTime( $request_data )
     {
+    	$ntp = FALSE;
+    	
     	try
     	{
     	    $dateTimeDto = SMTDateTimeDto::getInstance( $request_data );
     	    
-    	    //update OTU date time and SmartOtu timezone
-    	    $otu = new SMTOtu();
-    	    $otu->setContext( $this->getContext() );    	    
-    	    $otu->setOtuTimeStamp( $dateTimeDto->getTimestamp(), $dateTimeDto->getTimezoneSec(), $dateTimeDto->getTimezoneName(), $dateTimeDto->isTimezoneDst()  );
+    	    try
+    	    {
+    	    	$ntp = ( strcasecmp($this->sendReceive( SMTOtuApi::getNtpActive() ), 'TRUE' ) == 0 );
+    	    }
+    	    catch ( \Exception $e )
+    	    {
+    	    	$this->getContext()->getLogger()->traceException( $ex);
+    	    }
+    	    
+    	    if ( $ntp )
+    	    {
+    	    	$this->send( SMTOtuApi::getNtpSync() );
+    	    	
+    	    	//retrieve database connection
+    	    	$dbConnection = $this->getContext()->getDatabase();
+    	    	
+    	    	//update timezone in database settings
+    	    	$dto = SMTSystemConfigurationDto::fetch($dbConnection);
+    	    	$dto->setTimezoneSec( 0 );
+    	    	$dto->setTimezoneName( 'UTC' );
+    	    	$dto->setTimezoneDst( FALSE );
+    	    	$dto->save($dbConnection);
+    	    	$dbConnection->close();
+    	    }
+    	    else 
+    	    {
+    	    	//update OTU date time and SmartOtu timezone
+    	    	$otu = new SMTOtu();
+    	    	$otu->setContext( $this->getContext() );
+    	    	$otu->setOtuTimeStamp( $dateTimeDto->getTimestamp(), $dateTimeDto->getTimezoneSec(), $dateTimeDto->getTimezoneName(), $dateTimeDto->isTimezoneDst()  );
+    	    }
     	}
     	catch ( \Exception $e )
     	{
@@ -391,6 +420,7 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
     function checkOtuDateTime( $request_data )
     {
         $result = self::RESULT_OK;
+        $ntp = FALSE;
     	try
     	{
     		$dateTimeDto = SMTDateTimeDto::getInstance( $request_data );
@@ -412,21 +442,35 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         		SMTLogger::getInstance()->trace( "clientTimezoneName: ".$dateTimeDto->getTimezoneName());
         		SMTLogger::getInstance()->trace( sprintf("clientTimezoneDst: %b",$dateTimeDto->isTimezoneDst() ));
         		
+        		
         		//update OTU date time:
         		// - if it is not already set
-        		// - or if timezone are the same and if the drift is > 15mn
+        		// - or if timezone are the same and if the drift is > 15mn 
+        		// and ntp is not activated
         		if ( !isset( $currentTimezoneName ) || ($currentTimezoneName === NULL) ||
         		     ( (abs( $currentTimeStamp - $clientTimeStamp ) >  SMTSmartOtuSettings::getDateTimeMaxDrift() )
         		       && ( strcasecmp($currentTimezoneName, $dateTimeDto->getTimezoneName() ) == 0 ) 
         		     ) 
         		   )
         		{
-            		//update OTU date time and SmartOtu timezone
-            		$otu = new SMTOtu();
-            		$otu->setContext( $this->getContext() );
-            		$otu->setOtuTimeStamp( $dateTimeDto->getTimestamp(), $dateTimeDto->getTimezoneSec(), $dateTimeDto->getTimezoneName(), $dateTimeDto->isTimezoneDst() );
-            		//check failed: a new date was applied on OTU
-            		$result = self::RESULT_KO;
+        			try
+        			{
+        				$ntp = ( strcasecmp($this->sendReceive( SMTOtuApi::getNtpActive() ), 'TRUE' ) == 0 );
+        			}
+        			catch ( \Exception $e )
+        			{
+        				$this->getContext()->getLogger()->traceException( $ex);
+        			}
+        			
+        			if ( !$ntp )
+        			{
+	            		//update OTU date time and SmartOtu timezone
+	            		$otu = new SMTOtu();
+	            		$otu->setContext( $this->getContext() );
+	            		$otu->setOtuTimeStamp( $dateTimeDto->getTimestamp(), $dateTimeDto->getTimezoneSec(), $dateTimeDto->getTimezoneName(), $dateTimeDto->isTimezoneDst() );
+	            		//check failed: a new date was applied on OTU
+	            		$result = self::RESULT_KO;
+        			}
         		}
         		$this->getContext()->getDatabase()->close();
             }
