@@ -110,6 +110,9 @@ class SMTSwitchService extends SMTService implements SMTIService
     	    $configDetectSwitchDto->setDtssSwitch($this->getSwitchManager(TRUE)->isDtssSwitch());
     	    $configDetectSwitchDto->setSwitchDetectedHomogeneous($this->getSwitchManager(TRUE)->isSwitchDetectedHomogeneous());
     	    $configDetectSwitchDto->setIsOsxPowerOn($this->getSwitchManager(TRUE)->getOsxPowerOn());
+    	    $configDetectSwitchDto->setOTAMPossible($this->getSwitchManager(TRUE)->isMolexSwitchPossible());
+    	    $configDetectSwitchDto->setOTAMSwitch($this->getSwitchManager(TRUE)->hasMolexOSUDetected());
+    	    $configDetectSwitchDto->setModuleCompatibleWithSwitch($this->getSwitchManager(TRUE)->isModuleCompatibleWithSwitch());
     	}
     	catch ( \Exception $e )
     	{
@@ -155,6 +158,9 @@ class SMTSwitchService extends SMTService implements SMTIService
     		$configDetectSwitchDto->setVirtualSwitch($this->switchManager->hasVirtualSwitch());
     		$configDetectSwitchDto->setSwitchDetectedHomogeneous($this->switchManager->isSwitchDetectedHomogeneous());
     		$configDetectSwitchDto->setIsOsxPowerOn($this->switchManager->getOsxPowerOn());
+    		$configDetectSwitchDto->setOTAMPossible($this->switchManager->isMolexSwitchPossible());
+    		$configDetectSwitchDto->setOTAMSwitch($this->switchManager->hasMolexOSUDetected());
+    		$configDetectSwitchDto->setModuleCompatibleWithSwitch($this->switchManager->isModuleCompatibleWithSwitch());
     	}
     	catch ( \Exception $e )
     	{
@@ -276,6 +282,22 @@ class SMTSwitchService extends SMTService implements SMTIService
     		//update big topology status
     		$osxList->setIsBigTopology($this->switchManager->isBigTopology());
     		$osxList->setIsOsxPowerOn($this->switchManager->getOsxPowerOn());
+    		$osxList->setOTAMPossible($this->switchManager->isMolexSwitchPossible());
+    		$hasMolexOsu = FALSE;
+    		$hasJdsuOSU = $this->switchManager->hasJdsuOSUDetected();
+    		if ( !$hasJdsuOSU )
+    		{
+    			$hasMolexOsu = $this->switchManager->hasMolexOSUDetected();
+    		    if (!$hasMolexOsu)
+    		    {
+    		    	$hasJdsuOSU = $this->switchManager->hasJdsuOSU();
+    		    	if (!$hasJdsuOSU)
+    		    	{
+    		    		$hasMolexOsu= $this->switchManager->hasMolexOSU();
+    		    	}
+    		    }
+    		}
+    		$osxList->computeSwitchType($hasJdsuOSU, $hasMolexOsu);
     	}
     	catch ( \Exception $e )
     	{
@@ -291,10 +313,12 @@ class SMTSwitchService extends SMTService implements SMTIService
      * @access protected
      * @class SMTAccessControl {@requires install}
      */
-    function scanOsx()
+    function scanOsx( $request_data )
     {
     	try
-    	{    		
+    	{
+    		$otamScan = ($request_data != NULL && $request_data['otam'] != NULL)? filter_var( $request_data['otam'], FILTER_VALIDATE_BOOLEAN ) : FALSE;
+    		
     		if ( $this->switchManager == NULL )
     		{
     			$this->switchManager = new SMTSwitchManager();
@@ -304,11 +328,14 @@ class SMTSwitchService extends SMTService implements SMTIService
     		//OSX setup in progress
     		$this->switchManager->disableSequencer(TRUE);
     		
-    		$osxList= $this->switchManager->fullScan();
+    		$osxList= $this->switchManager->fullScan($otamScan);
     		
     		//update big topology status
     		$osxList->setIsBigTopology($this->switchManager->isBigTopology());
     		$osxList->setIsOsxPowerOn($this->switchManager->getOsxPowerOn());
+    		$osxList->setOTAMPossible($this->switchManager->isMolexSwitchPossible());
+
+    		$osxList->computeSwitchType(!$otamScan, $otamScan);
     	}
     	catch ( \Exception $e )
     	{
