@@ -231,6 +231,9 @@ class SMTModule extends SMTServiceHelper
         }
         $configDetectModuleDto->setMonitoringTests($monitoringTests);
         
+        $moduleCompatibleWithSwitch= strcasecmp( 'TRUE', $this->sendReceive( SMTOtuApi::CMD_check_module_compatibility_with_switch ) ) == 0;
+        $configDetectModuleDto->setModuleCompatibleWithSwitch($moduleCompatibleWithSwitch);
+        
         $index=0;
         $difference = FALSE;
         while ( $index < $moduleCount)
