@@ -1212,14 +1212,25 @@ class SMTLinkTest extends SMTServiceHelper
     	{
     		$testDetailString = $socket->sendReceive( SMTOtuApi::getTestDescriptionCommand( $testId ), FALSE );
     		preg_match_all("/\"(?:[^\"]*?)\",|(?:[^,]*?),/", $testDetailString.',', $output_array);
-    		$peakNumber= rtrim($output_array[0][14],",");
+    		
+    		//tests if it's a normal monitoring test or a high sensibility test (highsens, tapping...)
+    		$mode = rtrim($output_array[0][5],",");
+    		if ( SMTTestMode::isHighsensOrTappingMode( $mode) ) //high sensibility
+    		{
+    			$peakNumber= rtrim($output_array[0][14],",");
+    		}
+    		else
+    		{
+    			$thresholdCount= rtrim($output_array[0][11],",");
+    			$peakNumber= $thresholdCount - SMTThresholdBufferEncoderDecoder::TOPAZ_THRESHOLD_COUNT;
+    		}
     	}
     	catch( Exception $e )
     	{
     		$this->getContext()->getLogger()->traceException($e);
     		$peakNumber = 0;
     	}
-    	
+    	return $peakNumber;
     }
     
     /**
