@@ -34,7 +34,7 @@ class SMTSwitchDecoder
     private $switch_string = NULL;    
 
     /**
-     * OSU count per topologies excluding topologies M,N,P,Q,X,Y where the number of OSU is given directly in the configuration string
+     * OSU count per topologies excluding topologies M,N,O,P,Q,X,Y where the number of OSU is given directly in the configuration string
      */
     private $osu_Topologies = array("A"=>0,"B"=>1,"C"=>2,"D"=>1,"E"=>0,"F"=>0,"G"=>0,"H"=>0,"I"=>1,"J"=>1,"K"=>0,"L"=>4,"R"=>1, "T"=>2,"U"=>1);  
     
@@ -80,7 +80,7 @@ class SMTSwitchDecoder
         	$type  = substr($this->getSwitchEncodingString(), SMTSwitchDecoder::TOPOLOGY, 1);
         	
         	//for M,N,P,Q topologies the switch output count is given with 4 digits
-        	if ( $type == 'M' || $type == 'N' || $type == 'P' || $type == 'Q' || $type == 'X'|| $type == 'Y')
+        	if ( $type == 'M' || $type == 'N' || $type == 'O' || $type == 'P' || $type == 'Q' || $type == 'X'|| $type == 'Y')
         	{
         		$switchOutPut = substr($this->getSwitchEncodingString(), SMTSwitchDecoder::OUT_POSITION, 4);
         	}
@@ -90,7 +90,7 @@ class SMTSwitchDecoder
         		$switchOutPut = substr($this->getSwitchEncodingString(), SMTSwitchDecoder::OUT_POSITION, 3);
         	}
     	}
-        return intval( $switchOutPut );    
+        return intval( $switchOutPut );
     }     
     
     /**
@@ -104,8 +104,8 @@ class SMTSwitchDecoder
     	{
         	$type  = substr($this->getSwitchEncodingString(), SMTSwitchDecoder::TOPOLOGY, 1);
         	
-        	//for M,N,P,Q topologies the count of osus is set with 2 digits in the switch string
-        	if ( $type == 'M' || $type == 'N' || $type == 'P' || $type == 'Q' )
+        	//for M,N,O,P,Q topologies the count of osus is set with 2 digits in the switch string
+        	if ( $type == 'M' || $type == 'N' || $type == 'O' || $type == 'P' || $type == 'Q' )
         	{
         		$osuCount = intval( substr($this->getSwitchEncodingString(), SMTSwitchDecoder::OSU_COUNT, 2) );
         	}
@@ -132,7 +132,7 @@ class SMTSwitchDecoder
         	}
     	}
 
-        return $osuCount;    
+        return intval($osuCount);
     }  
         
     /**
@@ -152,6 +152,58 @@ class SMTSwitchDecoder
     	}
 
         return $osuDistributorPos;    
-    }      
+    }
+    
+    /**
+     * Whether There is an OSU distributor.
+     * 
+     * @return boolean Whether There is an OSU distributor.
+     */
+    function hasOSUDistributor()
+    {
+    	$osuDistributor = FALSE;
+    	
+    	$type  = substr($this->getSwitchEncodingString(), SMTSwitchDecoder::TOPOLOGY, 1);
+    	
+    	//for P,Q topologies there is a distributor OSU
+    	if ( $type == 'P' || $type == 'Q')
+    	{
+    		$osuDistributor = TRUE;
+    	}
+    	
+    	return $osuDistributor;
+    }
+    
+    /**
+     * Whether the topology uses OTAMs
+     * 
+     * @return boolean
+     */
+    function hasMolexOSU()
+    {
+    	$molex = FALSE;
+    	$customization = substr($this->getSwitchEncodingString(), SMTSwitchDecoder::CUSTOMISATION, 1);
+    	if ( $customization == 'A' || $customization == 'B' )
+    	{
+    		$molex = TRUE;
+    	}
+    	return $molex;
+    }
+    
+    /**
+     * Whether the topology uses JDSU OSU
+     *
+     * @return boolean
+     */
+    function hasJdsuOSU()
+    {
+    	$jdsu = FALSE;
+    	$customization = substr($this->getSwitchEncodingString(), SMTSwitchDecoder::CUSTOMISATION, 1);
+    	if ( $customization == '3' || $customization == '4' ||$customization == '6' || $customization == '7' || $customization == '8' || $customization == '9' )
+    	{
+    		$jdsu= TRUE;
+    	}
+    	return $jdsu;
+    }
 }
 ?>
\ No newline at end of file
