@@ -45,6 +45,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
 	const OSX_POWER_ON = "ON";
 	const OSX_POWER_OFF = "OFF";
 	const INVALID_PORT_STRING = '-> 0';
+	const INVALID_DESC_STRING = '-1';
 	
     /**
      * For smartOtu, no ROTAU can be used => macros switch id = 0
@@ -99,6 +100,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
      */
     function retrieve($forceDetection = TRUE)
     {
+    	
 //     	//in SmartOTU mode, if detection is forced, OSX alimentation must be turned on
 //     	if ( $forceDetection && SMTOtuMode::isSmartOtu() )
 //     	{
@@ -128,7 +130,6 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
         $this->switchDetectedHomogeneous = self::retrieveDetectedSwitchHomogeneous($this->getContext()->getOtuSocket() );
         
         $this->checkDtssSwitch();
-        
     }
     
     /**
@@ -188,14 +189,29 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
      */
     function getOsxPowerOn()
     {
-    	if ( SMTOtuType::isCOtu())
+    	//by default power is ON (power management not supported by OTU8kv2 old B43)
+    	$powerOn = TRUE;
+    	$queryPower = SMTOtuType::isCOtu();
+    	
+    	if ( SMTOtuType::isOtu8KV2() )
     	{
-    		return strcasecmp( SMTOtuApi::RES_ENABLED, $this->sendReceive( SMTOtuApi::CMD_get_power_on_off_osx ) ) == 0;    		
+    		$queryPower = strcasecmp( 'TRUE', $this->sendReceive( SMTOtuApi::CMD_get_switch_molex_available) ) == 0;
     	}
-    	else
+    	
+    	if ( $queryPower)
     	{
-    		return TRUE;
+    		try 
+    		{
+    			$res = $this->sendReceive( SMTOtuApi::CMD_get_power_on_off_osx );
+    			$powerOn = strcasecmp( SMTOtuApi::RES_ENABLED, $res ) == 0;
+    		}
+    		catch ( \Exception $e )
+    		{
+    			$powerOn = TRUE;
+    		}
     	}
+    	
+    	return $powerOn;
     }
     
     /**
@@ -279,11 +295,11 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     }
     
     /**
-     * Full scan of osxs limited to *idn?
+     * Full scan of osxs/OTAM limited to *idn?
      *
      * @return list of osxs full scan description
      */
-    function fullScan()
+    function fullScan($scanOTAM)
     {
     	$osxList = new SMTOsxListDto();
     	
@@ -292,25 +308,39 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     		$osxDesc = '';
     		try
     		{
-    			$osxDesc = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_switch_jdsu_idn, $i) );
-    			$osxDesc= preg_replace('/[[:^print:]]/', '', $osxDesc);
-    			try 
+    			if ( $scanOTAM )
     			{
-	    			$ports = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_osu_ports, $i) );
-	    			if ( substr( $ports, -strlen( self::INVALID_PORT_STRING ) ) == self::INVALID_PORT_STRING)
+    				$osxDesc = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_switch_molex_idn, $i) );
+    			}
+    			else
+    			{
+    				$osxDesc = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_switch_jdsu_idn, $i) );
+    			}
+    			$osxDesc= preg_replace('/[[:^print:]]/', '', $osxDesc);
+    			if ( $osxDesc == self::INVALID_DESC_STRING)
+    			{
+    				$osxDesc = '';
+    			}
+    			if ( strlen($osxDesc) > 0)
+    			{
+	    			try 
+	    			{
+		    			$ports = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_osu_ports, $i) );
+		    			if ( substr( $ports, -strlen( self::INVALID_PORT_STRING ) ) == self::INVALID_PORT_STRING)
+		    			{
+		    				$ports = '';
+		    			}
+	    			}
+	    			catch(\Exception $ex )
 	    			{
 	    				$ports = '';
 	    			}
+	    			$osx = new SMTOsxDto();
+	    			$osx->setIndex( $i );
+	    			$osx->setDescription($osxDesc);
+	    			$osx->setPorts($ports);
+	    			$osxList->addOsx($osx);
     			}
-    			catch(\Exception $ex )
-    			{
-    				$ports = '';
-    			}
-    			$osx = new SMTOsxDto();
-    			$osx->setIndex( $i );
-    			$osx->setDescription($osxDesc);
-    			$osx->setPorts($ports);
-    			$osxList->addOsx($osx);
     		}
     		//ports are retrieved from detection and can fail
     		catch ( \Exception $e )
@@ -487,13 +517,131 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     	return $this->switchDetectedHomogeneous;
     }
     
+    function hasMolexOSUDetected()
+    {
+    	$hasMolexSwitch = FALSE;
+    	try
+    	{
+    		if ( $this->switchDetect!= NULL )
+    		{
+    			$hasMolexSwitch = $this->switchDetect->hasMolexOSU();
+    		}
+    		else
+    		{
+    			$macroSwitchDet = new SMTMacroSwitchDet($this->getContext()->getOtuSocket());
+    			$hasMolexSwitch = $macroSwitchDet->hasMolexOSU();
+    		}
+    	}
+    	catch ( \Exception $e )
+    	{
+    		//no log : can fail if no switch is set in the OTU
+    		//SMTLogger::getInstance()->traceException($e);
+    	}
+    	
+    	return $hasMolexSwitch;
+    }
+    
+    function hasJdsuOSUDetected()
+    {
+    	$hasJdsuSwitch = FALSE;
+    	try
+    	{
+    		if ($this->switchDetect!= NULL)
+    		{
+    			$hasJdsuSwitch= $this->switchDetect->hasJdsuOSU();
+    		}
+    		else
+    		{
+    			$macroSwitchDet = new SMTMacroSwitchDet($this->getContext()->getOtuSocket());
+    			$hasJdsuSwitch= $macroSwitchDet->hasJdsuOSU();
+    		}
+    	}
+    	catch ( \Exception $e )
+    	{
+    		//no log : can fail if no switch is set in the OTU
+    		//SMTLogger::getInstance()->traceException($e);
+    	}
+    	return $hasJdsuSwitch;
+    }
+    
+    
+    function hasMolexOSU()
+    {
+    	$hasMolexSwitch = FALSE;
+    	try 
+    	{
+	    	if ( ($this->switchConfig != NULL) || ($this->switchDetect!= NULL) )
+	    	{
+	    		$hasMolexSwitch = ( ($this->switchConfig != NULL) && ($this->switchConfig->hasMolexOSU()) ) ||
+	    		( ($this->switchDetect!= NULL) && ($this->switchDetect->hasMolexOSU()) );
+	    	}
+	    	else
+	    	{
+	    		$macroSwitchConf = new SMTMacroSwitchConf($this->getContext()->getOtuSocket());
+	    		$hasMolexSwitch = $macroSwitchConf->hasMolexOSU();
+	    		if ( !$hasMolexSwitch )
+	    		{
+	    			$macroSwitchDet = new SMTMacroSwitchDet($this->getContext()->getOtuSocket());
+	    			$hasMolexSwitch = $macroSwitchDet->hasMolexOSU();
+	    		}
+	    	}
+    	}
+    	catch ( \Exception $e )
+    	{
+    		//no log : can fail if no switch is set in the OTU
+    		//SMTLogger::getInstance()->traceException($e);
+    	}
+    	
+        return $hasMolexSwitch;
+    }
+    
+    function hasJdsuOSU()
+    {
+    	$hasJdsuSwitch = FALSE;
+    	try
+    	{
+	    	if ( ($this->switchConfig != NULL) || ($this->switchDetect!= NULL) )
+	    	{
+	    		$hasJdsuSwitch= ( ($this->switchConfig != NULL) && ($this->switchConfig->hasJdsuOSU()) ) ||
+	    		( ($this->switchDetect!= NULL) && ($this->switchDetect->hasJdsuOSU()) );
+	    	}
+	    	else
+	    	{
+	    		$macroSwitchConf = new SMTMacroSwitchConf($this->getContext()->getOtuSocket());
+	    		$hasJdsuSwitch= $macroSwitchConf->hasJdsuOSU();
+	    		if ( !$hasJdsuSwitch)
+	    		{
+	    			$macroSwitchDet = new SMTMacroSwitchDet($this->getContext()->getOtuSocket());
+	    			$hasJdsuSwitch= $macroSwitchDet->hasJdsuOSU();
+	    		}
+	    	}
+    	}
+    	catch ( \Exception $e )
+    	{
+    		//no log : can fail if no switch is set in the OTU
+    		//SMTLogger::getInstance()->traceException($e);
+    	}
+    	return $hasJdsuSwitch;
+    }
+    
+    function isMolexSwitchPossible()
+    {
+    	return strcasecmp( 'TRUE', $this->sendReceive( SMTOtuApi::CMD_get_switch_molex_available) ) == 0;
+    }
+    
+    function isModuleCompatibleWithSwitch()
+    {
+    	return strcasecmp( 'TRUE', $this->sendReceive( SMTOtuApi::CMD_check_module_compatibility_with_switch ) ) == 0;
+    }
+    
+
     /**
      *
      * @return app\serviceshelper\otau\SMTMacroSwitchDet
      */
     function getDetectedSwitch()
     {
-        return $this->switchDetect;    
+        return $this->switchDetect;
     }
     
     /**
