@@ -24,6 +24,7 @@ use app\services\monitoring\SMTOtuMonitoringTestThresholdDto;
 use app\sharedmemory\SMTMemoryManager;
 use app\util\SMTLogger;
 use app\admin\SMTOtuMode;
+use app\serviceshelper\maintenance\SMTLicence;
 
 /**
  * SmartOTU settings manager:
@@ -38,7 +39,8 @@ class SMTSmartOtuSettings
     const SMART_OTU_VERSION_HEADER = "SOFTWARE VERSION";
     const INI_FILE = "data/settings.ini";
     
-    const OTU_MODE = "mode";    
+    const OTU_MODE = "mode";
+    const OTU_OPTION = "option";
     const MAP_URL  = "map";
     const SESSION_TIME_OUT = "session_timeout";
     const MESURE_UNIT = "measure_unit";
@@ -61,9 +63,11 @@ class SMTSmartOtuSettings
     private $otuAddress = self::DEFAULT_OTU_ADDRESS;
     // attention plus de mode par defaut!!!
     private $otuMode = NULL;
+    private $otuOption= NULL;
     //attention plus de type d'OTU par defaut!!!
     private $otuType = NULL;
     private $mapUrl = self::DEFAULT_MAP_URL;
+    private $restApi = NULL;
     
     /**
      * The OTU log level
@@ -147,7 +151,16 @@ class SMTSmartOtuSettings
             if( array_key_exists( SMTSmartOtuSettings::OTU_MODE, $conf_array) )
             {
             	$this->otuMode = $conf_array[SMTSmartOtuSettings::OTU_MODE];
-            }            
+            }
+            if( array_key_exists( SMTSmartOtuSettings::OTU_OPTION, $conf_array) )
+            {
+            	$this->otuOption = $conf_array[SMTSmartOtuSettings::OTU_OPTION];
+            }
+            else 
+            {   
+            	//by default no option
+            	$this->otuOption = "";
+            }
             if( (array_key_exists( SMTSmartOtuSettings::SESSION_TIME_OUT, $conf_array)) && $conf_array[SMTSmartOtuSettings::SESSION_TIME_OUT] > 1)
             {
                 $this->sessionTimeOut = intval($conf_array[SMTSmartOtuSettings::SESSION_TIME_OUT]);
@@ -594,7 +607,7 @@ class SMTSmartOtuSettings
     	}
     
     	return $otuMode;
-    }    
+    }
     
     /**
      * Register the otu mode in CACHE MEMORY
@@ -606,8 +619,68 @@ class SMTSmartOtuSettings
     	$settings = self::getOtuSettingsDto(TRUE);
     	$settings->setOtuMode( $otuMode );
     	$settings->save();
-    }    
+    }
+
+    /**
+     * Get the otu option from CACHE MEMORY.
+     * If mode is not found, try to parse again the settings file (link on settings file is created by OTU and could not exist when WebI looks for it)
+     *
+     * @return string The OTU mode or NULL (settings file link doesn't exist)
+     */
+    public static function getOtuOption()
+    {
+    	$otuOption = NULL;
+    	$settings = self::getOtuSettingsDto();
+    	if ( $settings != NULL )
+    	{
+    		$otuOption = $settings->getOtuOption();
+    	}
+    	
+    	if ( $otuOption == NULL )
+    	{
+    		//retrieve otu mode from settings file or use default value
+    		$otuOption =  self::getInstance()->otuOption;
+    		if ($otuOption != NULL)
+    		{
+    			self::setOtuOption($otuOption);
+    		}
+    		else
+    		{
+    			//force retrieval of settings
+    			self::getInstance()->retrieveSettings();
+    			$otuOption =  self::getInstance()->otuOption;
+    			if ($otuOption != NULL)
+    			{
+    				self::setOtuOption($otuOption);
+    			}
+    		}
+    	}
+    	
+    	return $otuOption;
+    }
     
+    /**
+     * Register the otu option in CACHE MEMORY
+     *
+     * @param string $otuOption The OTU mode.
+     */
+    public static function setOtuOption( $otuOption)
+    {
+    	if ( $otuOption != NULL )
+    	{
+    		$settings = self::getOtuSettingsDto(TRUE);
+    	}
+    	else
+    	{
+    		$settings = self::getOtuSettingsDto(FALSE);
+    	}
+    	if ( $settings != NULL )
+    	{
+    		$settings->setOtuOption( $otuOption);
+    		$settings->save();
+    	}
+    }
+
     /**
      * Get the otu mode from CACHE MEMORY.
      *
@@ -678,7 +751,7 @@ class SMTSmartOtuSettings
     	$settings = self::getOtuSettingsDto(TRUE);
     	$settings->setMapUrl( $mapUrl );
     	$settings->save();
-    }    
+    }
     
     /**
      * @param boolean $valid
@@ -704,7 +777,33 @@ class SMTSmartOtuSettings
             $smsOptionValid = $settings->isSmsOptionValid();
         }
         return ($smsOptionValid !== NULL)? filter_var($smsOptionValid, FILTER_VALIDATE_BOOLEAN) : NULL;
-    }    
+    }
+    
+    /**
+     * @param boolean $valid
+     */
+    public static function setRelayOptionValid ( $relayOptionValid )
+    {
+    	$settings = self::getOtuSettingsDto(TRUE);
+    	$settings->setRelayOptionValid( $relayOptionValid);
+    	$settings->save();
+    }
+    
+    /**
+     * Whether the Relay option is available on the OTU or NULL if the data wasn't yet retrieved
+     *
+     * @return boolean or NULL if not set
+     */
+    public static function isRelayOptionValid()
+    {
+    	$relayOptionValid= FALSE;
+    	$settings = self::getOtuSettingsDto();
+    	if ( $settings != NULL )
+    	{
+    		$relayOptionValid= $settings->isRelayOptionValid();
+    	}
+    	return ($relayOptionValid!== NULL)? filter_var($relayOptionValid, FILTER_VALIDATE_BOOLEAN) : NULL;
+    }
     
     /**
      * Register the default peaks thresholds
@@ -771,7 +870,18 @@ class SMTSmartOtuSettings
     public static function getDefaultBudgetVariationThresholds()
     {
     	return SMTSmartOtuThresholds::getDefaultBudgetVariationThresholds();
-    }           
+    }
+    
+    /**
+     * Get the otu tapping attenuation thresholds
+     *
+     * @return SMTOtuMonitoringTestThresholdDto The otu tapping attenuation thresholds.
+     *
+     */
+    public static function getDefaultTappingThresholds()
+    {
+    	return SMTSmartOtuThresholds::getDefaultTappingThresholds();
+    }
     
     /**
      * Get the Monitoring Acceptable Noise Margin (in Db) from cache or from ini file.
@@ -782,7 +892,18 @@ class SMTSmartOtuSettings
     public static function getMonitoringAcceptableNoiseMarginDbDefault()
     {
         return SMTSmartOtuThresholds::getMonitoringAcceptableNoiseMarginDbDefault();
-    }    
+    }
+    
+    /**
+     * Get the Tapping Acceptable Noise Margin (in Db) from cache or from ini file.
+     * Used to display that min noise level in trace viewer and to force user to set markers in traceviewer outside noise level.
+     *
+     * @return int Monitoring Acceptable Noise Margin (in Db)
+     */
+    public static function getTappingAcceptableNoiseMarginDbDefault()
+    {
+    	return SMTSmartOtuThresholds::getTappingAcceptableNoiseMarginDbDefault();
+    }
     
     /**
      * Get the delta between TO and BACK TO thresholds for attenuation (in Db) from cache or from ini file.
@@ -792,7 +913,17 @@ class SMTSmartOtuSettings
     public static function getAttenuationToBtoDeltaDbDefault()
     {
     	return SMTSmartOtuThresholds::getAttenuationToBtoDeltaDbDefault();
-    }    
+    }
+    
+    /**
+     * Get the delta between TO and BACK TO thresholds for tappingattenuation (in Db) from cache or from ini file.
+     *
+     * @return The delta between TO and BACK TO thresholds for attenuation (in Db)
+     */
+    public static function getTappingToBtoDeltaDbDefault()
+    {
+    	return SMTSmartOtuThresholds::getTappingToBtoDeltaDbDefault();
+    }
     
     /**
      * Get the attenuation critical threshold (in Db).
@@ -834,6 +965,34 @@ class SMTSmartOtuSettings
     	return SMTSmartOtuThresholds::getMonitorablePeakThresholdDbDefault();
     }
 
+    /**
+     * Whether REST API can be used.
+     *
+     * @return boolean or NULL if not found
+     */
+    public static function isRestApi()
+    {
+    	$restApi = NULL;
+    	$settings = self::getOtuSettingsDto();
+    	if ( $settings != NULL )
+    	{
+    		$restApi= $settings->isRestApi();
+    	}
+    	
+    	return $restApi;
+    }
+    
+    /**
+     * Set whether REST API can be used.
+     *
+     * @param boolean $restApi
+     */
+    public static function setRestApi( $restApi)
+    {
+    	$settings = self::getOtuSettingsDto(TRUE);
+    	$settings->setRestApi( $restApi);
+    	$settings->save();
+    }
 } 
 
 ?>
\ No newline at end of file
