@@ -11,6 +11,13 @@ DPORT=$3
 SSHPORT=$4
 TMP_SSH_RESULT="/tmp/ssh.result"
 TMP_SSH_PID="/tmp/ssh.pid"
+SSH_STRONG="$(fw_printenv ssh_strong | cut -f2 -d= )"
+
+if [[ "$SSH_STRONG" == "true" ]] ; then
+    PRIVATE_KEY="/home/secuser/.ssh/otu_id_rsa_4096"
+else
+    PRIVATE_KEY="/home/secuser/.ssh/otu_id_rsa"
+fi
 
 # ssh wait parameters (timeout is set to 15 seconds)
 COUNTER=0
@@ -35,7 +42,7 @@ rm -f $TMP_SSH_RESULT
 rm -f $TMP_SSH_PID
 
 # lancement et detachement de ssh en mode tunnel, timeout a 15 secondes
-ssh -p $SSHPORT -o ConnectTimeout=$TESTTIMEOUT -L $LPORT:localhost:$DPORT secuser@$IP -N 2> $TMP_SSH_RESULT &
+ssh -i $PRIVATE_KEY -p $SSHPORT -o ConnectTimeout=$TESTTIMEOUT -L $LPORT:localhost:$DPORT secuser@$IP -N 2> $TMP_SSH_RESULT &
 
 # get PID as command returned value, and save to file
 PID=$!
@@ -59,4 +66,4 @@ else
         # FAILURE : on ne laisse pas ssh en memoire si on sort en timeout
         kill $PID > /dev/null 2>&1
         exit 1
-fi
\ No newline at end of file
+fi
