@@ -64,7 +64,7 @@ for fd in $(ls /proc/$$/fd)
 SP_SSH1='mtsanywhere.updatemyunit.net' #OVH
 
 IS_OTU="no"
-[ -f /proc/device-tree/board/info-otu-board ] && [ $(hexdump /proc/device-tree/board/info-otu-board -n 4 -e '"%d"') -eq "3" ] && IS_OTU="yes"
+[ -f /proc/device-tree/board/info-otu-board ] && [ $(hexdump /proc/device-tree/board/info-otu-board -n 4 -e '"%d"') != "0" ] && IS_OTU="yes"
 
 source /etc/platform.conf
 
